@@ -4,7 +4,7 @@ use warnings;
 
 package Art::World {
 
-  our $VERSION = '0.18_13';
+  our $VERSION = '0.18_14';
 
   use Zydeco
     authority => 'cpan:SMONFF',
@@ -29,6 +29,7 @@ package Art::World {
   use Faker;
   use List::Util qw( max any );
   use Math::Round;
+  use Syntax::Keyword::Try qw( try );
   use Types::XSD qw( DateTime );
 
   role Abstraction {
@@ -58,15 +59,19 @@ package Art::World {
 
   role Buyer {
     requires money;           # Num $price
+    # TODO what if there are many buyers? Maybe we should remove the possibility
     method acquire ( Artwork $art ) {
+      # TODO the money paid should go to previous owner
+      $art->change_owner( $self );
       $self->money( $self->money - $art->value );
       push $self->collection->@*, $art;
       say "I bought for " . $art->value . " worth of art!" ;
     }
 
+    # TODO maybe not so necessary, since this process is made through the change_owner() method
     method sale ( Artwork $art ) {
       $self->money( $self->money + $art->value );
-      # TODO DELETE FROM COLLECTION
+      # TODO DELETE FROM OWNER'S COLLECTION
       # Using a grep filtering on the collection by id seems like a good idea
       # ...
       say "I sold !";
@@ -75,15 +80,20 @@ package Art::World {
 
   # Dunno how but the fact of being collected should bump artist reputation
   role Collectionable {
-    has owner  ( type => ArrayRef[ Collector ]);
+    has owner  (
+      default => sub { $_[0]->creator },
+      is => rw,
+      type => ArrayRef[ Agent ]);
     has value  ( is   => rw );
     has status (
       enum            => ['for_sale', 'sold'],
       # Create a delegated method for each value in the enumeration
       handles         => 1,
       default         => 'for_sale' );
-    method belongs_to {
-      return $self->owner;
+    method change_owner ( Agent $new_owner ) {
+
+      $self->owner->@* = ();
+      push $self->owner->@*, $new_owner ;
     }
   }
 
@@ -189,13 +199,15 @@ package Art::World {
 
     # In case a group of Agents are invited, for an Event like a performance, a concert
     multi method invite ( ArrayRef[ Agent ] *people,  Event *event  ) {
-
     }
-
   }
 
+  # The idea here is producing discourse about art
   role Language {
-    method speak {}
+    method speak ( Str $paroles) {
+      say $paroles;
+      # TODO Could write to a log file
+    }
   }
 
   role Manager {
@@ -284,8 +296,8 @@ package Art::World {
 
           class Gallery with Exhibit, Buyer {
 
-            has artwork (  type => ArrayRef );
-            has artist (  type => ArrayRef );
+            has artwork ( type => ArrayRef );
+            has artist ( type => ArrayRef );
             has event ( type => ArrayRef );
             has owner;
             has money;
@@ -515,22 +527,34 @@ understand how this is an artwork using programming.
 
 =head2 Abstraction
 
-This is were all kind of weird phenomenons happen. See the Manual about how it
-works.
+This is were all kind of weird phenomenons happen. See the
+L<Manual|Art::World::Manual> about how it works.
 
 =head2 Active
 
-Provide a C<participate> method.
+Is used to dissociate behaviors belonging to performers as opposed to the
+public. Provide a C<participate> method.
 
 =head2 Buyer
 
-Provide a C<aquire> method requiring some C<money>. All this behavior and
-attributes are encapsulated in the C<Buyer> role because there is no such thing
-as somebody in the art world that buy but doesn't sale.
+All this behavior and attributes are encapsulated in the C<Buyer> role because
+there is no such thing as somebody in the art world that buy but doesn't sale.
+
+The C<aquire> method is requiring some C<money>. C<acquire()> will remove the
+value of the C<Artwork> from the owner's money. The C<Artwork> is also added to
+it's C<Collection>.
+
+
 
 =head2 Collectionable
 
-If it's collectionable, it can go to a C<Collector> collection or in a C<Museum>.
+If it's collectionable, it can go to a C<Collector> collection or in a
+C<Museum>. A collectionable item is automatically owned by it's creator.
+
+When a C<Collector> C<acquire()> an C<Artwork>, the C<Artwork> C<ArrayRef> of
+owners is automatically cleared and substituted by the new owner(s).
+
+  $collector->acquire( $artwork );
 
 =head2 Crud
 
@@ -678,10 +702,18 @@ Something in a C<Magazine> of C<Website> about C<Art>, C<Exhibitions>, etc.
 In the beginning of their carreer they are usually underground and produce
 experimental art, but this can change in time.
 
-  $artist->is_underground if not $artist->has_collectors;
+  my $artist = Art::World->new_artist(
+    name => 'Andy Cassrol',
+  );
+
+  say $artist->is_homogenic;
+  #==> false
+
 
 After getting collected, artists become homogenic.
 
+  $artist->is_underground if not $artist->has_collectors;
+
 The artist got a lots of wonderful powers:
 
 =over
