@@ -38,7 +38,7 @@ Art::World::Util - Generating all kind of data for the Art::World
   say Art::World::Util->new_person->fake_name;
   #==> Firtname Lastname
 
-  Art::World::Util->new_math->pick( 10, 1000 ));
+  say Art::World::Util->new_math->pick( 10, 1000 ));
   #==> 666
 
 =head1 DESCRIPTION
@@ -46,6 +46,17 @@ Art::World::Util - Generating all kind of data for the Art::World
 C<Art::World::Util> provide useful generation tools for automated C<Agents>
 creation.
 
+=head2 Methods
+
+=head3 fake_name
+
+Generate a complete person name using L<Faker>.
+
+=head3 pick
+
+Pick an integer between a range that can be passed as a parameter. Mostly a way
+to not have to memorize C<$min + int ( rand ( $max - $min ))>.
+
 =head1 AUTHOR
 
 Sébastien Feugère <sebastien@feugere.net>
